@@ -1,9 +1,10 @@
-#  tests for cupy-8.6.0-py38hf95616d_0 (this is a generated file);
-print('===== testing package: cupy-8.6.0-py38hf95616d_0 =====');
+#  tests for cupy-9.0.0-py38hf95616d_0 (this is a generated file);
+print('===== testing package: cupy-9.0.0-py38hf95616d_0 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 # Configure CuPy to use 1 GPU for testing
 import os
+import site
 import sys
 os.environ["CUPY_TEST_GPU_LIMIT"] = "1"
 
@@ -12,6 +13,19 @@ cuda_path = os.environ.get('CUDA_PATH')
 assert cuda_path is not None
 print("CUDA_PATH:", cuda_path)
 
+# check _wheel.json exists
+# note that we don't rely on cupy.__file__ because we cannot import CuPy on Windows
+pypaths = site.getsitepackages()
+for cp in pypaths:
+    config_json = os.path.join(cp, 'cupy/.data/_wheel.json')
+    if not os.path.isfile(config_json):
+        continue
+    else:
+        print("_wheel.json is found:", config_json)
+        break
+else:
+    raise RuntimeError('_wheel.json is not found in the package')
+
 # Now that conda-forge docker images have libcuda.so, so "import cupy" would not fail
 # on Linux. However, tests would fail on the Azure CI since there is no GPU. See the
 # discussion in https://github.com/conda-forge/cupy-feedstock/pull/59#issuecomment-629584090.
@@ -47,4 +61,4 @@ py.test.cmdline.main(["tests/cupy_tests"])
 py.test.cmdline.main(["tests/cupyx_tests"])
 #  --- run_test.py (end) ---
 
-print('===== cupy-8.6.0-py38hf95616d_0 OK =====');
+print('===== cupy-9.0.0-py38hf95616d_0 OK =====');
